==> haskell-authenticate-oauth-1.6-71-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate-oauth
version: 1.6
id: authenticate-oauth-1.6-JfEuAd46up7HnsonxYNbrX
key: authenticate-oauth-1.6-JfEuAd46up7HnsonxYNbrX
license: BSD-3-Clause
maintainer: Hiromi Ishii, Artem Chirkin
author: Hiromi Ishii
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Library to authenticate with OAuth for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.
category: Web
abi: 3c150549b681869ab2b567e43e47ca7a
exposed: True
exposed-modules:
    Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs: /usr/lib/ghc-8.6.4/site-local/authenticate-oauth-1.6
library-dirs: /usr/lib/ghc-8.6.4/site-local/authenticate-oauth-1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/authenticate-oauth-1.6
hs-libraries: HSauthenticate-oauth-1.6-JfEuAd46up7HnsonxYNbrX
depends:
    RSA-2.3.1-2B5mne19f50Gmd4zw9NsyL SHA-1.6.4.4-1GMMHy6WdrlGpMrtGTWHUv
    base-4.12.0.0 base64-bytestring-1.0.0.2-EJ1mkGsqs004EmS9lh2uZC
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    crypto-pubkey-types-0.4.3-LIsnhfvfMMf1JkcBTE1XeD
    data-default-0.7.1.1-3C0tdSCD1lzIk8WkrvBOoZ
    http-client-0.6.2-FYzm0eoFnV2JqsXDvGiJPm
    http-types-0.12.3-IdIFkPvozmRFdXetXaEgxE
    random-1.1-3ypV4EIycgb35PKjTYYr5q time-1.8.0.2 transformers-0.5.6.2
    transformers-compat-0.6.2-IT1pgM4Lod5B9rerVXsOk7
haddock-interfaces: /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock
haddock-html: /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-authenticate-oauth-1.6-72-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-authenticate-oauth.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: authenticate-oauth
version: 1.6
id: authenticate-oauth-1.6-Hn14leIS5mJ6KibfVFQNYY
key: authenticate-oauth-1.6-Hn14leIS5mJ6KibfVFQNYY
license: BSD-3-Clause
maintainer: Hiromi Ishii, Artem Chirkin
author: Hiromi Ishii
stability: Stable
homepage: http://github.com/yesodweb/authenticate
synopsis: Library to authenticate with OAuth for Haskell web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/authenticate-oauth>.
category: Web
abi: 4111db01f803822c97a10460bdd95e38
exposed: True
exposed-modules:
    Web.Authenticate.OAuth Web.Authenticate.OAuth.IO
import-dirs: /usr/lib/ghc-8.6.4/site-local/authenticate-oauth-1.6
library-dirs: /usr/lib/ghc-8.6.4/site-local/authenticate-oauth-1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/authenticate-oauth-1.6
hs-libraries: HSauthenticate-oauth-1.6-Hn14leIS5mJ6KibfVFQNYY
depends:
    RSA-2.3.1-2B5mne19f50Gmd4zw9NsyL SHA-1.6.4.4-1GMMHy6WdrlGpMrtGTWHUv
    base-4.12.0.0 base64-bytestring-1.0.0.2-EJ1mkGsqs004EmS9lh2uZC
    blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC bytestring-0.10.8.2
    crypto-pubkey-types-0.4.3-LIsnhfvfMMf1JkcBTE1XeD
    data-default-0.7.1.1-GPAEdZkaAwALFGM1Pbeyt4
    http-client-0.6.2-FYzm0eoFnV2JqsXDvGiJPm
    http-types-0.12.3-IdIFkPvozmRFdXetXaEgxE
    random-1.1-3ypV4EIycgb35PKjTYYr5q time-1.8.0.2 transformers-0.5.6.2
    transformers-compat-0.6.2-IT1pgM4Lod5B9rerVXsOk7
haddock-interfaces: /usr/share/doc/haskell-authenticate-oauth/html/authenticate-oauth.haddock
haddock-html: /usr/share/doc/haskell-authenticate-oauth/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
